<?php

/*
Snippet Name: planyo
Short Desc: Planyo online reservation system snippet
Version: 2.6
Created By: Xtreeme GmbH
Home Page: http://www.planyo.com/
Documentation: http://www.planyo.com/modx-reservation-system/
Tags: online, reservation, booking, system, reserve, book, software

Usage:

For demo purposes you may use the snippet without any parameters:
ON MODX REVOLUTION: [[!planyo]]
ON MODX EVOLUTION: [!planyo!]
Otherwise, as a minimum, the snippet requires your site ID (if you don't have one, create a new site at www.planyo.com)
ON MODX REVOLUTION: [[!planyo? &site=`11`]]
ON MODX EVOLUTION: [!planyo? &site=`11`!]
Note: Use [[!planyo]] instead of [[planyo]] to disable caching (old evolution syntax: [!planyo!]). This is required when using the SEO-friendly mode (which is the default).

Parameters:

Required
--------
NONE

Optional
--------
&site -- planyo site ID (default: 'demo' = demo site)

&language -- Language of the user interface (default: EN = English); currently supported languages: EN, FR, DE, IT, ES, PL, DA, FI, SE, IS, RO, RU, EL, NL. You can also modify the templates (in your planyo administration panel) to display the language choice to the user or pass the language as a parameter in the URL (lang)

&extra_search_fields -- comma-separated extra fields in the search box (default: none), example: 'Number of persons'. You first need to define these fields in settings/custom resource properties

&sort_fields -- comma-separated sort fields (default: none); a single field will hide the sort dropdown box. Allowed values: name, price, prop_res_xxx (custom resource properties)

&default_mode -- Choose the initial mode (default: 'resource_list'): 'search' to allow clients to search for available dates or 'resource_list' to display a list of all resources (in such case search must be initiated by embedding an extra search box -- see last step of integration in Planyo's admin panel) or 'upcoming_availability' to
  show a quick view of upcoming availability. Choosing 'empty' will not display anything by default but will require you to either pass the resource ID to the module as parameter in the URL (resource_id) or add an external search box or calendar preview

&seo_friendly -- 'true' or 'false' (default: true); Choose whether the plugin in the resource list and resource details modes should be SEO friendly (information retrieved from the server when loading the page) or not (information retrieved using Javascript/AJAX). Choosing yes will add a slight delay to the loading time of the page but will let search engines index the resource names, descriptions and photos.

&resource_ordering -- Sorting criterium for the listing of resources in the resource list view (default: 'name'). This can be set to name which sorts by resource name, or one of prop_res_xxx (custom resource property defined in Planyo)

&use_login -- 'true' or 'false' (default: false); Choose whether the plugin should use the login information from this modx site. If used, the reservation form items will be automatically prefilled with known values and subsequent reservations will use previously entered data.

&login_integration_code -- If integration with modx login is switched on, you'll need to enter the login integration code which you'll find in advanced integration settings in the Planyo backend

&js_framework -- One of: 'jquery', 'jquery-noinclude'; Specify if jQuery should be included by this plugin (use the value 'jquery') or if your website already includes jQuery (use the value 'jquery-noinclude')

&attribute_string -- Optional attribute string which can be used to add additional parameters to the planyo plugin

*/

require_once($modx->config['base_path'].'assets/snippets/planyo/planyo-plugin-impl.php');

global $planyo_site_id, $planyo_files_location, $planyo_language, $planyo_always_use_ajax, $planyo_sort_fields, $planyo_resource_id, $planyo_js_library_used, $planyo_include_js_library, $planyo_default_mode, $planyo_extra_search_fields, $planyo_login_info, $planyo_resource_ordering, $planyo_attribs;

$planyo_site_id = isset($site) ? trim($site, "'`") : 'demo';  // ID of your planyo site. It can be a number or the default value ('demo') to see demonstration of the plugin
$planyo_files_location = $modx->config['base_url'].'assets/snippets/planyo';  // relative or absolute directory where the planyo files are kept (usually '/planyo-files')
$planyo_language = isset($language) ? trim($language, "'`") : 'EN';  // you can optionally change the language here, e.g. 'FR' or 'ES' or pass the languge in the 'lang' parameter
$seo_friendly_tr = trim($seo_friendly, "'`");
$planyo_always_use_ajax = ($seo_friendly_tr=='1' || $seo_friendly_tr=='true' || !isset($seo_friendly)) ? false : true;  // set to true to use AJAX to display resource list and resource details views
$planyo_sort_fields = isset($sort_fields) ? trim($sort_fields, "'`") : '';  // comma-separated sort fields -- a single field will hide the sort dropdown box
$planyo_resource_ordering = isset($resource_ordering) ? trim($resource_ordering, "'`") : '';
$planyo_extra_search_fields = isset($extra_search_fields) ? trim($extra_search_fields, "'`") : '';  // comma-separated extra fields in the search box
$planyo_default_mode = isset($default_mode) ? trim($default_mode, "'`") : 'resource_list';
$planyo_attribs = isset($attribute_string) ? $attribute_string : "";
$login_integration_code = isset($login_integration_code) ? $login_integration_code : "";

$planyo_resource_id = null;  // optional: ID of the resource being reserved
$planyo_js_library_used = (!isset($js_framework) || $js_framework == 'jquery' || $js_framework == 'jquery-noinclude') ? 'jquery' : 'mootools';  // jquery or mootools
$planyo_include_js_library = !isset($js_framework) || $js_framework == 'jquery' || $js_framework == 'mootools'; // set to false if you already include jQuery on your site
$use_login_tr = trim($use_login, "'`");
if ($modx->user && $modx->user->getOne('Profile') && ($use_login_tr=='1' || $use_login_tr=='true')) {
  $profile = $modx->user->getOne('Profile');
  $names = explode(" ",$profile->get('fullname'));
  if (is_array($names) && count($names) > 1) {
    $last_name = array_pop($names);
    $first_name = implode(" ", $names);
  }
  else {
    $first_name = null;
    $last_name = null;
  }
  $planyo_login_info = array('first_name'=>$first_name, 'last_name'=>$last_name, 'email'=>$profile->get('email'), 'address'=>$profile->get('address'), 'city'=>$profile->get('city'), 'zip'=>$profile->get('zip'), 'state'=>$profile->get('state'), 'mobile_number_param'=>$profile->get('mobilephone'), 'phone'=>$profile->get('phone'), 'login_cs'=>$login_integration_code ? sha1($profile->get('email') . $login_integration_code) : 'nocode');
}

echo "<div id='planyo_plugin_code' class='planyo'>";
planyo_setup();
echo "</div>";

?>